Simple Moscow Mule Recipe
Author: https://www.facebook.com/allrecipes
Description: This Moscow mule cocktail is made with a 2-1 ratio of ginger beer to vodka, plus the juice of half a lime. Serve it in a copper mug to keep it cold!

Skip to content

# Simple Moscow Mule

4.9
(52)
42 Reviews
15 Photos

This Moscow mule with a 2-1 ratio of ginger beer to vodka is similar to a Dark and Stormy cocktail but made with vodka instead of rum.

Recipe by Lorem Ipsum
Updated on November 9, 2022
Saved!
View All Saved Items

15
15
15
15
Prep Time:
10 mins
Total Time:
10 mins
Servings:
1
Jump to Nutrition Facts

## Ingredients

- 1 cup ice, or as needed

- ½ medium lime, juiced

- 2 fluid ounces vodka

- 4 fluid ounces ginger beer, or to taste

- 2 lime slices

## Directions

1. Fill a tall glass with ice. Pour in lime juice, then vodka, then ginger beer. Garnish with lime slices.

## Nutrition Facts (per serving)

192 | Calories
0g | Fat
17g | Carbs
0g | Protein

Nutrition Facts
Servings Per Recipe 1
Calories 192
% Daily Value *
Total Fat 0g | 0%
Sodium 11mg | 0%
Total Carbohydrate 17g | 6%
Dietary Fiber 1g | 3%
Total Sugars 14g
Protein 0g
Vitamin C 13mg | 64%
Calcium 18mg | 1%
Iron 0mg | 1%
Potassium 50mg | 1%

* Percent Daily Values are based on a 2,000 calorie diet. Your daily values may be higher or lower depending on your calorie needs.

** Nutrient information is not available for all ingredients. Amount is based on available nutrient data.

(-) Information is not currently available for this nutrient. If you are following a medically restrictive diet, please consult your doctor or registered dietitian before preparing this recipe for personal consumption.

Powered by the ESHA Research Database © 2018, ESHA Research, Inc. All Rights Reserved

## Photos of Simple Moscow Mule

You’ll Also Love
Saved!
View All Saved Items
Gold Rush
Pineapple Moscow Mule
2 Ratings
Kombucha Mule
Why Are Moscow Mules Served in Copper Mugs?
Moscow Mule Cocktail
121 Ratings
Limoncello Moscow Mule
1 Rating
Ginger-Hibiscus Sparkler
17 Quick and Easy Cocktails for Your Home Happy Hour
Watermelon Mojitos
4 Ratings
25 Popular Cocktail Recipes You Just Have to Know if You Love Making Drinks at Home
Cosmopolitan Cocktail
29 Ratings
The Perfect Margarita
43 Ratings
Texas Tea
4 Ratings
Jalapeño Margaritas
50 Ratings
Ginger Beer vs. Ginger Ale: What's the Difference?
The Top 50 Cocktail List and Recipes
Newsletter Sign Up

By clicking “Accept All Cookies”, you agree to the storing of cookies on your device to enhance site navigation, analyze site usage, and assist in our marketing efforts.